@@ -1,6 +1,7 @@
 import pytest
 
 from hypercorn.middleware import HTTPToHTTPSRedirectMiddleware
+from hypercorn.typing import HTTPScope, WebsocketScope
 from ..helpers import empty_framework
 
 
@@ -14,7 +15,22 @@ async def test_http_to_https_redirect_middleware_http(raw_path: bytes) -> None:
         nonlocal sent_events
         sent_events.append(message)
 
-    scope = {"type": "http", "scheme": "http", "raw_path": raw_path, "query_string": b"a=b"}
+    scope: HTTPScope = {
+        "type": "http",
+        "asgi": {},
+        "http_version": "2",
+        "method": "GET",
+        "scheme": "http",
+        "path": raw_path.decode(),
+        "raw_path": raw_path,
+        "query_string": b"a=b",
+        "root_path": "",
+        "headers": [],
+        "client": ("127.0.0.1", 80),
+        "server": None,
+        "extensions": {},
+    }
+
     await app(scope, None, send)
 
     assert sent_events == [
@@ -37,11 +53,19 @@ async def test_http_to_https_redirect_middleware_websocket(raw_path: bytes) -> N
         nonlocal sent_events
         sent_events.append(message)
 
-    scope = {
+    scope: WebsocketScope = {
         "type": "websocket",
+        "asgi": {},
+        "http_version": "1.1",
         "scheme": "ws",
+        "path": raw_path.decode(),
         "raw_path": raw_path,
         "query_string": b"a=b",
+        "root_path": "",
+        "headers": [],
+        "client": None,
+        "server": None,
+        "subprotocols": [],
         "extensions": {"websocket.http.response": {}},
     }
     await app(scope, None, send)
@@ -65,12 +89,19 @@ async def test_http_to_https_redirect_middleware_websocket_http2() -> None:
         nonlocal sent_events
         sent_events.append(message)
 
-    scope = {
+    scope: WebsocketScope = {
         "type": "websocket",
+        "asgi": {},
         "http_version": "2",
         "scheme": "ws",
+        "path": "/abc",
         "raw_path": b"/abc",
         "query_string": b"a=b",
+        "root_path": "",
+        "headers": [],
+        "client": None,
+        "server": None,
+        "subprotocols": [],
         "extensions": {"websocket.http.response": {}},
     }
     await app(scope, None, send)
@@ -94,12 +125,20 @@ async def test_http_to_https_redirect_middleware_websocket_no_rejection() -> Non
         nonlocal sent_events
         sent_events.append(message)
 
-    scope = {
+    scope: WebsocketScope = {
         "type": "websocket",
+        "asgi": {},
         "http_version": "2",
         "scheme": "ws",
+        "path": "/abc",
         "raw_path": b"/abc",
         "query_string": b"a=b",
+        "root_path": "",
+        "headers": [],
+        "client": None,
+        "server": None,
+        "subprotocols": [],
+        "extensions": {},
     }
     await app(scope, None, send)
 
@@ -111,11 +150,19 @@ def test_http_to_https_redirect_new_url_header() -> None:
     new_url = app._new_url(
         "https",
         {
-            "type": "http",
-            "scheme": "http",
+            "http_version": "1.1",
+            "asgi": {},
+            "method": "GET",
             "headers": [(b"host", b"localhost")],
-            "raw_path": b"/",
+            "path": "/",
+            "root_path": "",
             "query_string": b"",
+            "raw_path": b"/",
+            "scheme": "http",
+            "type": "http",
+            "client": None,
+            "server": None,
+            "extensions": {},
         },
     )
     assert new_url == "https://localhost/"
