@@ -44,7 +44,7 @@ async def test_protocol_send_response(protocol: H11Protocol) -> None:
             RawData(
                 data=(
                     b"HTTP/1.1 201 \r\ndate: Thu, 01 Jan 1970 01:23:20 GMT\r\n"
-                    b"server: hypercorn-h11\r\nconnection: close\r\n\r\n"
+                    b"server: hypercorn-h11\r\nConnection: close\r\n\r\n"
                 )
             )
         )
@@ -71,7 +71,7 @@ async def test_protocol_send_body(protocol: H11Protocol) -> None:
     assert protocol.send.call_args_list == [
         call(
             RawData(
-                data=b"HTTP/1.1 200 \r\ncontent-length: 5\r\ndate: Thu, 01 Jan 1970 01:23:20 GMT\r\nserver: hypercorn-h11\r\nconnection: close\r\n\r\n"  # noqa: E501
+                data=b"HTTP/1.1 200 \r\ncontent-length: 5\r\ndate: Thu, 01 Jan 1970 01:23:20 GMT\r\nserver: hypercorn-h11\r\nConnection: close\r\n\r\n"  # noqa: E501
             )
         ),
         call(RawData(data=b"hello")),
@@ -98,20 +98,24 @@ async def test_protocol_send_stream_closed(
 
 @pytest.mark.asyncio
 async def test_protocol_instant_recycle(protocol: H11Protocol) -> None:
+    # This test task acts as the asgi app, spawned tasks act as the
+    # server.
     data = b"GET / HTTP/1.1\r\nHost: hypercorn\r\n\r\n"
     # This test requires a real event as the handling should pause on
     # the instant receipt
     protocol.can_read = EventWrapper()
-    await protocol.handle(RawData(data=data))
+    task = asyncio.ensure_future(protocol.handle(RawData(data=data)))
+    await asyncio.sleep(0)  # Switch to task
     assert protocol.stream is not None
+    assert task.done()
     await protocol.stream_send(Response(stream_id=1, status_code=200, headers=[]))
     await protocol.stream_send(EndBody(stream_id=1))
     task = asyncio.ensure_future(protocol.handle(RawData(data=data)))
     await asyncio.sleep(0)  # Switch to task
     await protocol.stream_send(StreamClosed(stream_id=1))
+    await asyncio.sleep(0)  # Switch to task
     # Should have recycled, i.e. a stream should exist
     assert protocol.stream is not None
-    await asyncio.sleep(0)  # Switch to task
     assert task.done()
 
 
@@ -265,8 +269,12 @@ async def test_protocol_handle_h2c_upgrade(protocol: H11Protocol) -> None:
     assert protocol.send.call_args_list == [
         call(
             RawData(
-                b"HTTP/1.1 101 \r\nupgrade: h2c\r\ndate: Thu, 01 Jan 1970 01:23:20 GMT\r\n"
-                b"server: hypercorn-h11\r\n\r\n"
+                b"HTTP/1.1 101 \r\n"
+                b"date: Thu, 01 Jan 1970 01:23:20 GMT\r\n"
+                b"server: hypercorn-h11\r\n"
+                b"connection: upgrade\r\n"
+                b"upgrade: h2c\r\n"
+                b"\r\n"
             )
         )
     ]
